@@ -203,7 +203,7 @@ def log_match_data(match: Match):
             logging.info(f"  {name} ({format_mmr(player.mmr)}){local_player_marker}")
 
         # Log information about the players the local player interacted with
-        if enemies:
+        if any(player.killed_by_me or player.killed_me for player in enemies):
             logging.info("Enemies:")
             for player in enemies:
                 if player.killed_by_me:
